Index: chrome/common/chrome_notification_types.h |
diff --git a/chrome/common/chrome_notification_types.h b/chrome/common/chrome_notification_types.h |
index f0cd5006205722649131452f2b758003202d71b0..77f7f2a1812531317f0a88e4141da18541ac1d78 100644 |
--- a/chrome/common/chrome_notification_types.h |
+++ b/chrome/common/chrome_notification_types.h |
@@ -1101,9 +1101,13 @@ enum NotificationType { |
// containing the committed preview. |
NOTIFICATION_INSTANT_COMMITTED, |
// Sent when the Instant loader determines whether the page supports the |
// Instant API or not. |
- NOTIFICATION_INSTANT_SUPPORT_DETERMINED, |
+ NOTIFICATION_INSTANT_OVERLAY_SUPPORT_DETERMINED, |
+ |
+ // Sent when the Instant Controller determines whether the ntp supports the |
+ // Instant API or not. |
+ NOTIFICATION_INSTANT_NTP_SUPPORT_DETERMINED, |
// Sent when the CaptivePortalService checks if we're behind a captive portal. |
// The Source is the Profile the CaptivePortalService belongs to, and the |
@@ -1101,9 +1101,13 @@ enum NotificationType { |
// containing the committed preview. |
NOTIFICATION_INSTANT_COMMITTED, |
- // Sent when the Instant loader determines whether the page supports the |
+ // Sent when the Instant Controller determines whether the overlay supports the |
// Instant API or not. |